@@ -1,6 +1,6 @@
-from ChatstatTikTokApi import ChatstatTikTokApi
+from TikTokApi import TikTokApi
 
-with ChatstatTikTokApi() as api:
+with TikTokApi() as api:
     sound = api.sound(id="7016547803243022337")
 
     for video in sound.videos():
